Conversation class

IM Conversation of RTM Plugin.

Implementers

Properties

attributes → Map?
Custom field, no strict limit, can store any valid data.
no setter
client → Client
Which Client that the Conversation belongs to.
final
createdAt → DateTime?
The created date of the Conversation.
no setter
creator → String?
The creator of the Conversation.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the Conversation, it will never be null.
final
isMuted → bool
Indicates whether the Conversation.client has muted offline notifications about this Conversation.
no setter
isUnique → bool
Indicates whether the Conversation is normal and unique. The uniqueness is based on the members when creating.
no setter
lastDeliveredAt → DateTime?
The last date of the Message which has been delivered to other Client.
no setter
lastMessage → Message?
The last Message in the Conversation.
no setter
lastMessageDate → DateTime?
The date of the last Message in the Conversation.
no setter
lastMessageTimestamp → int?
The timestamp of the last Message in the Conversation.
no setter
lastReadAt → DateTime?
The last date of the Message which has been read by other Client.
no setter
members → List?
The members of the Conversation.
no setter
name → String?
Custom field, generally use it to show the name of the Conversation.
no setter
rawData → Map
The raw data of the Conversation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueID → String?
If the Conversation.isUnique is true, then it will have a unique-ID.
no setter
unreadMessageCount → int
The count of the unread Message for the Conversation.client.
no setter
unreadMessageMentioned → bool
Indicates whether the unread Message list contians any message that mentions the Conversation.client.
no setter
updatedAt → DateTime?
The last updated date of the Conversation.
no setter

Methods

addMembers({required Set<String> members}) → Future<MemberResult>
To add members to the Conversation.
blockMembers({required Set<String> members}) → Future<MemberResult>
To block members from the Conversation.
call({required String method, required Map arguments}) → Future
inherited
countMembers() → Future<int>
To get the count of the Conversation.members.
errorFrom(Map result) → RTMException
inherited
fetchReceiptTimestamps() → Future<void>
To fetch last receipt timestamps of the Message.
isFailure(Map result) → bool
inherited
join() → Future<MemberResult>
To let the Conversation.client join to the Conversation.
mute() → Future<void>
To turn off the offline notifications for Conversation.client about this Conversation.
muteMembers({required Set<String> members}) → Future<MemberResult>
To mute members from the Conversation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseIsoString(String? isoString) → DateTime?
inherited
parseMilliseconds(int? milliseconds) → DateTime?
inherited
queryBlockedMembers({int? limit = 50, String? next}) → Future<QueryMemberResult>
Get the blocked members in the conversation.
queryMessage({int? startTimestamp, String? startMessageID, bool? startClosed, int? endTimestamp, String? endMessageID, bool? endClosed, MessageQueryDirection? direction, int? limit = 20, int? type}) → Future<List<Message>>
To query the history of the Message which has been sent.
queryMutedMembers({int? limit = 50, String? next}) → Future<QueryMemberResult>
Get the muted members in the conversation.
quit() → Future<MemberResult>
To let the Conversation.client quit from the Conversation.
read() → Future<void>
To read Conversation.lastMessage in the Conversation.
recallMessage({Message? message, String? messageID, int? messageTimestamp}) → Future<RecalledMessage>
To recall a sent Message.
removeMembers({required Set<String> members}) → Future<MemberResult>
To remove members from the Conversation.
send({required Message message, bool? transient, bool? receipt, bool? will, MessagePriority? priority, Map? pushData}) → Future<Message>
To send a Message in the Conversation.
toString() → String
A string representation of this object.
inherited
unblockMembers({required Set<String> members}) → Future<MemberResult>
To unblock members from the Conversation.
unmute() → Future<void>
To turn on the offline notifications for Conversation.client about this Conversation.
unmuteMembers({required Set<String> members}) → Future<MemberResult>
To unmute members from the Conversation.
updateInfo({required Map<String, dynamic> attributes}) → Future<void>
To update attributes of the Conversation.
updateMessage({Message? oldMessage, String? oldMessageID, int? oldMessageTimestamp, required Message newMessage}) → Future<Message>
To update content of a sent Message.

Operators

operator ==(Object other) → bool
The equality operator.
inherited