ConversationQuery class

IM Conversation Query of RTM Plugin.

Properties

client → Client
Which Client that the ConversationQuery belongs to.
final
condition ↔ _LCCompositionalCondition
getter/setter pair
excludeMembers ↔ bool?
Whether the queried Conversations not contain Conversation.members, default is false.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeLastMessage ↔ bool?
Whether the queried Conversations contain Conversation.lastMessage, default is false.
getter/setter pair
limit ↔ int?
The max count of the query result, default is 10.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skip ↔ int?
The offset of the query, default is 0.
getter/setter pair
sort ↔ String?
The order by the key of Conversation.
getter/setter pair
whereString ↔ String?
The String representation of the where condition.
getter/setter pair

Methods

addAscendingOrder(String key) → ConversationQuery
Adding a ascending order by the value corresponding to key to the order.
addDescendingOrder(String key) → ConversationQuery
Adding a descending order by the value corresponding to key to the order.
call({required String method, required Map arguments}) → Future
inherited
errorFrom(Map result) → RTMException
inherited
find<T extends Conversation>() → Future<List<T>>
To find the Conversation.
findTemporaryConversations({required List<String> temporaryConversationIDs}) → Future<List<TemporaryConversation>>
To find the TemporaryConversation by IDs.
isFailure(Map result) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderByAscending(String key) → ConversationQuery
The ascending order by the value corresponding to key, support for multi-field sorting with comma.
orderByDescending(String key) → ConversationQuery
The descending order by the value corresponding to key, support for multi-field sorting with comma.
parseIsoString(String? isoString) → DateTime?
inherited
parseMilliseconds(int? milliseconds) → DateTime?
inherited
toString() → String
A string representation of this object.
inherited
whereContainedIn(String key, List values) → ConversationQuery
values contains value corresponding to key, or values contains at least one element in the array corresponding to key.
whereContains(String key, String subString) → ConversationQuery
The string corresponding to key has a subString.
whereContainsAll(String key, List values) → ConversationQuery
The array corresponding to key contains all elements in values.
whereDoesNotExist(String key) → ConversationQuery
The field corresponding to key does not exist.
whereEndsWith(String key, String suffix) → ConversationQuery
The string corresponding to key has a suffix.
whereEqualTo(String key, dynamic value) → ConversationQuery
The value corresponding to key is equal to value, or the array corresponding to key contains value.
whereExists(String key) → ConversationQuery
The field corresponding to key exists.
whereGreaterThan(String key, dynamic value) → ConversationQuery
The value corresponding to key is greater than value.
whereGreaterThanOrEqualTo(String key, dynamic value) → ConversationQuery
The value corresponding to key is greater than or equal to value.
whereLessThan(String key, dynamic value) → ConversationQuery
The value corresponding to key is less than value.
whereLessThanOrEqualTo(String key, dynamic value) → ConversationQuery
The value corresponding to key is less than or equal to value.
whereMatches(String key, String regex, {String? modifiers}) → ConversationQuery
The string corresponding to key matches regex. modifiers reference:
whereNotContainedIn(String key, List values) → ConversationQuery
values does not contain value corresponding to key, or the field corresponding to key does not exist.
whereNotEqualTo(String key, dynamic value) → ConversationQuery
The value corresponding to key is not equal to value, or the array corresponding to key does not contain value.
whereSizeEqualTo(String key, int size) → ConversationQuery
The size of the array corresponding to key is equal to size.
whereStartsWith(String key, String prefix) → ConversationQuery
The string corresponding to key has a prefix.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

and(List<ConversationQuery> queries) → ConversationQuery
Performs a logical AND operation on an array of one or more queries.
or(List<ConversationQuery> queries) → ConversationQuery
Performs a logical OR operation on an array of one or more queries.