MemberResult class

The result of operations for Conversation.members.

Properties

allSucceeded → bool
All targets of the operation are suceeded.
no setter
failedMembers → List
All not allowed targets and reasons.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
succeededMembers → List
All allowed targets.
final

Methods

call({required String method, required Map arguments}) → Future
inherited
errorFrom(Map result) → RTMException
inherited
isFailure(Map result) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseIsoString(String? isoString) → DateTime?
inherited
parseMilliseconds(int? milliseconds) → DateTime?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited