Message class

IM Message of RTM Plugin.

Implementers

Constructors

Message()
To create a new Message.

Properties

binaryContent ↔ Uint8List?
The binary content of the Message.
getter/setter pair
conversationID → String?
The Conversation.id of the Conversation which the Message belong to.
no setter
deliveredDate → DateTime?
The date representation of the Message.deliveredTimestamp.
no setter
deliveredTimestamp ↔ int?
The timestamp when the Message has been delivered to other.
getter/setter pair
fromClientID → String?
The Client.id of the Client who send the Message.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the Message.
no setter
isTransient → bool
Indicates whether this Message is transient.
no setter
mentionAll ↔ bool?
Whether all members in the Conversation are mentioned by the Message.
getter/setter pair
mentionMembers ↔ List?
The members in the Conversation mentioned by the Message.
getter/setter pair
patchedDate → DateTime?
The date representation of the Message.patchedTimestamp.
no setter
patchedTimestamp → int?
The timestamp when update the Message, unit is millisecond.
no setter
readDate → DateTime?
The date representation of the Message.readTimestamp.
no setter
readTimestamp ↔ int?
The timestamp when the Message has been read by other.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentDate → DateTime?
The date representation of the Message.sentTimestamp.
no setter
sentTimestamp → int?
The timestamp when send the Message, unit is millisecond.
no setter
status → MessageStatus
The status of the Message.
no setter
stringContent ↔ String?
The string content of the Message.
getter/setter pair

Methods

call({required String method, required Map arguments}) → Future
inherited
errorFrom(Map result) → RTMException
inherited
isFailure(Map result) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseIsoString(String? isoString) → DateTime?
inherited
parseMilliseconds(int? milliseconds) → DateTime?
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited