QueryMemberResult class

Properties

hashCode → int
The hash code for this object.
no setterinherited
members → List
final
next → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({required String method, required Map arguments}) → Future
inherited
errorFrom(Map result) → RTMException
inherited
isFailure(Map result) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseIsoString(String? isoString) → DateTime?
inherited
parseMilliseconds(int? milliseconds) → DateTime?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited