RTMException class

Exception of RTM Plugin.

Implemented types

Constructors

RTMException({required String code, String? message, dynamic details})
To create a RTMException, code is needed.

Properties

code → String
The code of the RTMException, it will never be null.
final
details → dynamic
The supplementary information of the RTMException, it is optional.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The reason of the RTMException, it is optional.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited