VideoMessage class

IM Video Message of RTM Plugin.

Inheritance

Constructors

VideoMessage()
To create a new VideoMessage.
VideoMessage.from({String? path, Uint8List? binaryData, String? url, String? format, String? name})
To create a new VideoMessage from path or binaryData or url.

Properties

attributes ↔ Map?
The default getter for attributes of the TypedMessage.
getter/setter pairinherited
binaryContent ↔ Uint8List?
The binary content of the Message.
getter/setter pairinherited
conversationID → String?
The Conversation.id of the Conversation which the Message belong to.
no setterinherited
deliveredDate → DateTime?
The date representation of the Message.deliveredTimestamp.
no setterinherited
deliveredTimestamp ↔ int?
The timestamp when the Message has been delivered to other.
getter/setter pairinherited
duration → double?
The duration of the video file, unit is second.
no setter
format → String?
The format extension of the file.
no setterinherited
fromClientID → String?
The Client.id of the Client who send the Message.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the Message.
no setterinherited
isTransient → bool
Indicates whether this Message is transient.
no setterinherited
mentionAll ↔ bool?
Whether all members in the Conversation are mentioned by the Message.
getter/setter pairinherited
mentionMembers ↔ List?
The members in the Conversation mentioned by the Message.
getter/setter pairinherited
patchedDate → DateTime?
The date representation of the Message.patchedTimestamp.
no setterinherited
patchedTimestamp → int?
The timestamp when update the Message, unit is millisecond.
no setterinherited
rawData → Map
The raw data of the TypedMessage.
no setterinherited
readDate → DateTime?
The date representation of the Message.readTimestamp.
no setterinherited
readTimestamp ↔ int?
The timestamp when the Message has been read by other.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentDate → DateTime?
The date representation of the Message.sentTimestamp.
no setterinherited
sentTimestamp → int?
The timestamp when send the Message, unit is millisecond.
no setterinherited
size → double?
The size of the file, unit is byte.
no setterinherited
status → MessageStatus
The status of the Message.
no setterinherited
stringContent ↔ String?
The string content of the Message.
getter/setter pairinherited
text ↔ String?
The default getter for text of the TypedMessage.
getter/setter pairinherited
type → int
Using int to enumerate type of the TypedMessage.
no setteroverride
url → String?
The URL of the file.
no setterinherited

Methods

call({required String method, required Map arguments}) → Future
inherited
errorFrom(Map result) → RTMException
inherited
isFailure(Map result) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseIsoString(String? isoString) → DateTime?
inherited
parseMilliseconds(int? milliseconds) → DateTime?
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited